// SPDX-License-Identifier: BSL-1.0
#include <random>
#include <string>

#ifndef BUNDLED_CATCH2
#ifdef CATCH3
#include "catch2/catch_all.hpp"
#else
#include "catch2/catch.hpp"
#endif
#else
#include "../third-party/catch.hpp"
#endif

#include <termpaint.h>

